aboutsummaryrefslogtreecommitdiff
path: root/Lib/fontTools/misc/macCreatorType.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/fontTools/misc/macCreatorType.py')
-rw-r--r--Lib/fontTools/misc/macCreatorType.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/fontTools/misc/macCreatorType.py b/Lib/fontTools/misc/macCreatorType.py
index fb237200..6b191054 100644
--- a/Lib/fontTools/misc/macCreatorType.py
+++ b/Lib/fontTools/misc/macCreatorType.py
@@ -1,4 +1,4 @@
-from fontTools.misc.py23 import Tag, bytesjoin, strjoin
+from fontTools.misc.textTools import Tag, bytesjoin, strjoin
try:
import xattr
except ImportError:
@@ -18,7 +18,7 @@ def getMacCreatorAndType(path):
path (str): A file path.
Returns:
A tuple of two :py:class:`fontTools.py23.Tag` objects, the first
representing the file creator and the second representing the
file type.
"""
@@ -18,7 +18,7 @@ def getMacCreatorAndType(path):
path (str): A file path.
Returns:
- A tuple of two :py:class:`fontTools.py23.Tag` objects, the first
+ A tuple of two :py:class:`fontTools.textTools.Tag` objects, the first
representing the file creator and the second representing the
file type.